@@ -1,6 +1,8 @@
 #include <unistd.h>
 
 int main(int argn, char **argv, char **envp) {
+    setreuid(geteuid(),geteuid());
+    setregid(getegid(),getegid());
     argv[0] = SYMPASOAP;
     execve(SYMPASOAP,argv,envp);
 }
