@@ -24,7 +24,7 @@ package SOAP::XMLSchema1999::Serializer;
 
 package sympasoap;
 
-use strict vars;
+use strict "vars";
 
 use Exporter;
 use HTTP::Cookies;
@@ -35,7 +35,6 @@ my @EXPORT = ();
 use Conf;
 use Log;
 use Auth;
-use CAS;
 use Language;
 
 ## Define types of SOAP type listType
@@ -175,19 +174,17 @@ sub login {
 	    ->faultdetail("Incorrect password for user $email or bad login");
     } 
 
-    my $expire =  &Conf::get_robot_conf($robot,'cookie_expire');
-
-    unless(&cookielib::set_cookie_soap($email,$Conf::Conf{'cookie'},$http_host,$expire)) {
-	&Log::do_log('notice', 'SOAP : could not set HTTP cookie for external_auth');
-	die SOAP::Fault->faultcode('Server')
-	    ->faultstring('Cookie not set')
-	    ->faultdetail('Could not set HTTP cookie for external_auth');
-    }
+    ## Create SympaSession object
+    my $session = new SympaSession($robot, {'cookie' => $ENV{'SESSION_ID'}});
+    $ENV{'USER_EMAIL'} = $email;
+    $session->{'email'} = $email;
+    $session->store();
+    
+    ## Note that id_session changes each time it is saved in the DB
+    $ENV{'SESSION_ID'} = $session->{'id_session'};
 
     ## Also return the cookie value
-    return SOAP::Data->name('result')->type('string')->value(&cookielib::get_mac($email,$Conf::Conf{'cookie'}));
-
-#    return SOAP::Data->name('result')->type('boolean')->value(1);
+    return SOAP::Data->name('result')->type('string')->value($ENV{'SESSION_ID'});
 }
 
 sub casLogin {
@@ -206,6 +203,13 @@ sub casLogin {
 	    ->faultdetail('Use : <HTTP host> <proxyTicket>');
     }
     
+	unless ( eval "require AuthCAS" ){
+		do_log('err',"Unable to use AuthCAS library, install AuthCAS (CPAN) first");
+		return undef ;
+    }
+    require AuthCAS;
+
+	
     ## Validate the CAS ST against all known CAS servers defined in auth.conf
     ## CAS server response will include the user's NetID
     my ($user, @proxies, $email, $cas_id);
@@ -213,13 +217,13 @@ sub casLogin {
 	my $auth_service = $Conf{'auth_services'}{$robot}[$service_id];
 	next unless ($auth_service->{'auth_type'} eq 'cas'); ## skip non CAS entries
 	
-	my $cas = new CAS(casUrl => $auth_service->{'base_url'}, 
+	my $cas = new AuthCAS(casUrl => $auth_service->{'base_url'}, 
 			  #CAFile => '/usr/local/apache/conf/ssl.crt/ca-bundle.crt',
 			  );
 	
 	($user, @proxies) = $cas->validatePT(&Conf::get_robot_conf($robot,'soap_url'), $proxyTicket);
 	unless (defined $user) {
-	    &do_log('err', 'CAS ticket %s not validated by server %s : %s', $proxyTicket, $auth_service->{'base_url'}, &CAS::get_errors());
+	    &do_log('err', 'CAS ticket %s not validated by server %s : %s', $proxyTicket, $auth_service->{'base_url'}, &AuthCAS::get_errors());
 	    next;
 	}
 
@@ -245,19 +249,17 @@ sub casLogin {
 	    ->faultdetail("Could not get email address from LDAP directory");
     }
 
-    my $expire = &Conf::get_robot_conf($robot,'cookie_expire');
-
-    unless(&cookielib::set_cookie_soap($email,$Conf::Conf{'cookie'},$http_host,$expire)) {
-	&Log::do_log('notice', 'SOAP : could not set HTTP cookie for external_auth');
-	die SOAP::Fault->faultcode('Server')
-	    ->faultstring('Cookie not set')
-	    ->faultdetail('Could not set HTTP cookie for external_auth');
-    }
+    ## Create SympaSession object
+    my $session = new SympaSession($robot, {'cookie' => $ENV{'SESSION_ID'}});
+    $ENV{'USER_EMAIL'} = $email;
+    $session->{'email'} = $email;
+    $session->store();
+    
+    ## Note that id_session changes each time it is saved in the DB
+    $ENV{'SESSION_ID'} = $session->{'id_session'};
 
     ## Also return the cookie value
-    return SOAP::Data->name('result')->type('string')->value(&cookielib::get_mac($email,$Conf::Conf{'cookie'}));
-
-#    return SOAP::Data->name('result')->type('boolean')->value(1);
+    return SOAP::Data->name('result')->type('string')->value($ENV{'SESSION_ID'});
 }
 
 ## Used to call a service as an authenticated user without using HTTP cookies
@@ -265,38 +267,30 @@ sub casLogin {
 sub authenticateAndRun {
     my ($self, $email, $cookie, $service, $parameters) = @_;
 
-    &do_log('notice','authenticateAndRun(%s,%s,%s,%s)', $email, $cookie, $service, join(',',@$parameters));
+    my $session_id = $cookie;
+    &do_log('notice','authenticateAndRun(%s,%s,%s,%s)', $email, $session_id, $service, join(',',@$parameters));
 
-    unless ($cookie and $service) {
+    unless ($session_id and $service) {
+      &do_log('err', "Missing parameter");
 	die SOAP::Fault->faultcode('Client')
 	    ->faultstring('Incorrect number of parameters')
 	    ->faultdetail('Use : <email> <cookie> <service>');
     }
     my $auth ;
     
-    if ($email eq 'unkown') {
-	($email,$auth) = &wwslib::get_email_from_cookie($cookie,$Conf::Conf{'cookie'});
-	do_log('debug','get email from cookie : %s',$email);
-	unless ($email or ($email eq 'unkown')  ) {
-	    die SOAP::Fault->faultcode('Client')
-		->faultstring('Could not get email from cookie')
-		->faultdetail('');
-	}
-    }
 
-    my $checksum=&cookielib::get_mac($email, $Conf::Conf{'cookie'});
-    ## This test's purpose is to ensure that we are presented the right cookie. In addition, we avoid the following
-    ## problem: if the cookie is composed of digits only ([0-9]) AND it starts with at least one zero character, 
-    ## it is treated as a number and the leading zeros are ignored. When tested against checksum, it is not the same
-    ## character string as the leading zeros are missing. We add a number comparison to avoid it. Example: 00785136 becomes 785136.
-    unless (($cookie eq $checksum)||($checksum == $cookie)) {
-	&do_log('notice', "authenticateAndRun(): authentication failed Incorrect cookie $cookie <> $checksum)");
-	die SOAP::Fault->faultcode('Server')
-	    ->faultstring('Authentification failed')
-	    ->faultdetail("Incorrect cookie $cookie for user $email (checksum : $checksum)");
+    ## Provided email is not trusted, we fetch the user email from the session_table instead
+    my $session = new SympaSession($ENV{'SYMPA_ROBOT'},{'cookie' => $session_id});
+    $email = $session->{'email'} if (defined $session);
+    unless ($email or ($email eq 'unkown')  ) {
+      &do_log('err', "Failed to authenticate user with session ID $session_id");
+      die SOAP::Fault->faultcode('Client')
+	->faultstring('Could not get email from cookie')
+	  ->faultdetail('');
     }
-
+    
     $ENV{'USER_EMAIL'} = $email;
+    $ENV{'SESSION_ID'} = $session_id;
 
     &{$service}($self,@$parameters);
 }
@@ -308,32 +302,23 @@ sub getUserEmailByCookie {
     &do_log('debug3','getUserEmailByCookie(%s)', $cookie);
     
     unless ($cookie) {
-	die SOAP::Fault->faultcode('Client')
-	    ->faultstring('Incorrect  parameter')
-	    ->faultdetail('Use : <cookie>');
+      &do_log('err',"Missing parameter cookie");
+      die SOAP::Fault->faultcode('Client')
+	->faultstring('Missing parameter')
+	  ->faultdetail('Use : <cookie>');
     }
-    my ($auth,$email) ;
     
-    ($email,$auth) = &wwslib::get_email_from_cookie($cookie,$Conf::Conf{'cookie'});
-    do_log('debug','getUserEmailByCookie : %s',$email);
-    unless ($email or ($email eq 'unkown')  ) {
+    my $session = new SympaSession($ENV{'SYMPA_ROBOT'}, {'cookie' => $cookie});
+    
+    
+    unless (defined $session && ($session->{'email'} ne 'unkown')  ) {
+      &do_log('err',"Failed to load session for $cookie");
 	die SOAP::Fault->faultcode('Client')
 	    ->faultstring('Could not get email from cookie')
 	    ->faultdetail('');
-    }
-    
-    my $checksum=&cookielib::get_mac($email, $Conf::Conf{'cookie'});
-    ## This test's purpose is to ensure that we are presented the right cookie. In addition, we avoid the following
-    ## problem: if the cookie is composed of digits only ([0-9]) AND it starts with at least one zero character, 
-    ## it is treated as a number and the leading zeros are ignored. When tested against checksum, it is not the same
-    ## character string as the leading zeros are missing. We add a number comparison to avoid it. Example: 00785136 becomes 785136.
-    unless (($cookie eq $checksum)||($checksum == $cookie)) {
-	&do_log('notice', "getUserEmailByCookie(): invalid cookie ($cookie <> $checksum)");
-	die SOAP::Fault->faultcode('Server')
-	    ->faultstring('Authentification failed')
-	    ->faultdetail("Incorrect cookie $cookie for user $email");
-    }
-    return SOAP::Data->name('result')->type('string')->value($email);
+    }    
+
+    return SOAP::Data->name('result')->type('string')->value($session->{'email'});
     
 }
 ## Used to call a service from a remote proxy application
@@ -623,6 +608,7 @@ sub createList {
 	 }
      }
      return SOAP::Data->name('result')->type('boolean')->value(1);
+
 }
 
 sub closeList {
@@ -762,10 +748,13 @@ sub add {
     }else {
 	my $u;
 	my $defaults = $list->get_default_user_options();
+	my $u2 = &List::get_user_db($email);
 	%{$u} = %{$defaults};
 	$u->{'email'} = $email;
-	$u->{'gecos'} = $gecos;
+	$u->{'gecos'} = $gecos || $u2->{'gecos'};
 	$u->{'date'} = $u->{'update_date'} = time;
+	$u->{'password'} = $u2->{'password'} || &tools::tmp_passwd($email) ;
+	$u->{'lang'} = $u2->{'lang'} || $list->{'admin'}{'lang'};
 	
 	unless ($list->add_user($u)) {
 	    &Log::do_log('info', 'add %s@%s %s from %s : Unable to add user', $listname,$robot,$email,$sender);
@@ -777,16 +766,9 @@ sub add {
 	$list->delete_subscription_request($email);
     }
     
-    if ($List::use_db) {
-	my $u = &List::get_user_db($email);	
-	&List::update_user_db($email, {'lang' => $u->{'lang'} || $list->{'admin'}{'lang'},
-				       'password' => $u->{'password'} || &tools::tmp_passwd($email)
-				       });
-    }
-    
-    ## Now send the welcome file to the user if it exists.
-    unless ($quiet || ($action =~ /quiet/i )) {
-	unless ($list->send_file('welcome', $email, $robot,{})) {
+    ## Now send the welcome file to the user if it exists and notification is supposed to be sent.
+    unless ($quiet || $action =~ /quiet/i) {
+	unless ($list->send_file('welcome', $email, $robot,{'auto_submitted' => 'auto-generated'})) {
 	    &do_log('notice',"Unable to send template 'welcome' to $email");
 	}
     }
@@ -871,7 +853,7 @@ sub del {
     }
 
     my $user_entry = $list->get_subscriber($email);
-    unless ((defined $user_entry) && ($user_entry->{'subscribed'} == 1)) {
+    unless ((defined $user_entry)) {
 	    &do_log('info', 'DEL %s %s from %s refused, not on list', $listname, $email, $sender);
 	    die SOAP::Fault->faultcode('Client')
 		->faultstring('Not subscribed')
@@ -880,29 +862,22 @@ sub del {
     
     my $gecos = $user_entry->{'gecos'};
     
-    if ($user_entry->{'included'} == 1) {
-	unless ($list->update_user($email, {'subscribed' => 0, 'update_date' => time})) {
-	    &do_log('info', 'DEL %s %s from %s failed, database update failed', $email, $listname, $sender);
-	    die SOAP::Fault->faultcode('Server')
-		->faultstring('Unable to update subscriber informations')
-		->faultdetail('Database update failed');	    
-	}
-    } else {
-	## Really delete and rewrite to disk.
-	my $u;
-	unless ($u = $list->delete_user($email)){
-	    my $error = "Unable to delete user $email from list $listname for command 'del'";
-	    &do_log('info', 'DEL %s %s from %s failed, '.$error);
-	    die SOAP::Fault->faultcode('Server')
-		->faultstring('Unable to remove subscriber informations')
-		->faultdetail('Database access failed');	  
-	}
+    
+    ## Really delete and rewrite to disk.
+    my $u;
+    unless ($u = $list->delete_user('users' => [$email], 'exclude' =>' 1')){
+	my $error = "Unable to delete user $email from list $listname for command 'del'";
+	&do_log('info', 'DEL %s %s from %s failed, '.$error);
+	die SOAP::Fault->faultcode('Server')
+	    ->faultstring('Unable to remove subscriber informations')
+	    ->faultdetail('Database access failed');	  
     }
     
+    
     ## Send a notice to the removed user, unless the owner indicated
     ## quiet del.
-    unless ($quiet || ($action =~ /quiet/i )) {
-	unless ($list->send_file('removed', $email, $robot, {})) {
+    unless ($quiet || $action =~ /quiet/i) {
+	unless ($list->send_file('removed', $email, $robot, {'auto_submitted' => 'auto-generated'})) {
 	    &do_log('notice',"Unable to send template 'removed' to $email");
 	}
     }
@@ -1098,7 +1073,7 @@ sub signoff {
 	}
 	
 	## Really delete and rewrite to disk.
-	$list->delete_user($sender);
+	$list->delete_user('users' => [$sender], 'exclude' =>' 1');
 
 	## Notify the owner
 	if ($action =~ /notify/i) {
@@ -1361,6 +1336,20 @@ sub which {
 	if ($list->is_user($sender)) {
 	    $result_item->{'isSubscriber'} = 1;
 	}
+	## determine bounce informations of this user for this list
+ 
+	my $subscriber ;
+	if($subscriber = $list->get_subscriber($sender)) { 
+	    $result_item->{'bounceCount'} = 0;
+	    if ($subscriber->{'bounce'} =~ /^(\d+)\s+(\d+)\s+(\d+)(\s+(.*))?$/) {
+		$result_item->{'firstBounceDate'} =  $1;
+		$result_item->{'lastBounceDate'} = $2;
+		$result_item->{'bounceCount'} = $3;
+		if ($4 =~ /^(\d+\.(\d+\.\d+))$/) {
+		    $result_item->{'bounceCode'} = $1;
+		}	
+	    }
+	}
 	
 	my $listInfo;
 	if ($mode eq 'complex') {
@@ -1423,7 +1412,7 @@ sub get_reason_string {
     my $string;
     my $tt2_include_path =  &tools::make_tt2_include_path($robot,'mail_tt2','','');
 
-    unless (&tt2::parse_tt2($data,'authorization.tt2' ,\$string, $tt2_include_path)) {
+    unless (&tt2::parse_tt2($data,'authorization_reject.tt2' ,\$string, $tt2_include_path)) {
 	my $error = &tt2::get_error();
 	&List::send_notify_to_listmaster('web_tt2_error', $robot, [$error]);
 	&do_log('info', "get_reason_string : error parsing");
