@@ -1,5 +1,5 @@
 /* familyqueue.c - This program does the messages spooling
-   RCS Identication ; $Revision: 4399 $ ; $Date: 2007-05-15 14:01:14 +0200 (mar 15 mai 2007) $ 
+   RCS Identication ; $Revision: 6491 $ ; $Date: 2010-06-09 11:50:02 +0200 (mer 09 jun 2010) $ 
 
    Sympa - SYsteme de Multi-Postage Automatique
    Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -26,7 +26,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-static char rcsid[] = "(@)$Id: familyqueue.c 4399 2007-05-15 12:01:14Z olivier.salaun $";
+static char rcsid[] = "(@)$Id: familyqueue.c 6491 2010-06-09 09:50:02Z sympa-authors $";
 
 static char     qfile[128];
 static char     buf[16384];
@@ -74,6 +74,8 @@ readconf(char *file)
       if (s != NULL)
          strcpy(s, r);
    }
+   else
+      s = SPOOLDIR "/automatic";
    return s;
 }
 
