@@ -1,5 +1,5 @@
 # Conf.pm - This module does the sympa.conf and robot.conf parsing
-# RCS Identication ; $Revision: 7334 $ ; $Date: 2012-04-24 15:12:12 +0200 (mar 24 avr 2012) $ 
+# RCS Identication ; $Revision: 7509 $ ; $Date: 2012-07-23 13:00:44 +0200 (lun 23 jui 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -35,6 +35,7 @@ use wwslib;
 use confdef;
 use tools;
 use Sympa::Constants;
+use Data::Dumper;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(%Conf DAEMON_MESSAGE DAEMON_COMMAND DAEMON_CREATION DAEMON_ALL);
@@ -67,6 +68,7 @@ my %old_params = (
     msgcat                 => 'localedir',
     queueexpire            => '',
     clean_delay_queueother => '',
+    dkim_header_list => '',
     web_recode_to          => 'filesystem_encoding',
 );
 
@@ -226,6 +228,26 @@ sub load {
 	$Conf{$i} = $o{$i}[0] || $params{$i}->{'default'};
     }
 
+    # Hack because multi valued parameters are not available for Sympa 6.1.
+    if (defined $Conf{'automatic_list_families'}) {
+	my @families = split ';',$Conf{'automatic_list_families'};
+	my %families_description;
+	foreach my $family_description (@families) {
+	    my %family;
+	    my @family_parameters = split ':',$family_description;
+	    foreach my $family_parameter (@family_parameters) {
+		my @parameter = split '=', $family_parameter;
+		$family{$parameter[0]} = $parameter[1];
+	    }
+	    $family{'escaped_prefix_separator'} = $family{'prefix_separator'};
+	    $family{'escaped_prefix_separator'} =~ s/([+*?.])/\\$1/g;
+	    $family{'escaped_classes_separator'} = $family{'classes_separator'};
+	    $family{'escaped_classes_separator'} =~ s/([+*?.])/\\$1/g;
+	    $families_description{$family{'name'}} = \%family;
+	    $families_description{$family{'name'}}{'description'} = &load_automatic_lists_description(undef,$family{'name'});
+	}
+	$Conf{'automatic_list_families'} = \%families_description;
+    }
     ## Some parameters depend on others
     unless ($Conf{'css_url'}) {
 	$Conf{'css_url'} = $Conf{'static_content_url'}.'/css';
@@ -588,6 +610,28 @@ sub load_robots {
 	$robot_conf->{$robot}{'pictures_url'} ||= $robot_conf->{$robot}{'static_content_url'}.'/pictures/';
 	$robot_conf->{$robot}{'pictures_path'} ||= $robot_conf->{$robot}{'static_content_path'}.'/pictures/';
 	$robot_conf->{$robot}{'pictures_feature'} ||= $Conf{'pictures_feature'};
+	
+	# Hack because multi valued parameters are not available for Sympa 6.1.
+	if (defined $robot_conf->{$robot}{'automatic_list_families'}) {
+	    my @families = split ';',$robot_conf->{$robot}{'automatic_list_families'};
+	    my %families_description;
+	    foreach my $family_description (@families) {
+		my %family;
+		my @family_parameters = split ':',$family_description;
+		foreach my $family_parameter (@family_parameters) {
+		    my @parameter = split '=', $family_parameter;
+		    $family{$parameter[0]} = $parameter[1];
+		}
+		$family{'escaped_prefix_separator'} = $family{'prefix_separator'};
+		$family{'escaped_prefix_separator'} =~ s/([+*?.])/\\$1/g;
+		$family{'escaped_classes_separator'} = $family{'classes_separator'};
+		$family{'escaped_classes_separator'} =~ s/([+*?.])/\\$1/g;
+		$families_description{$family{'name'}} = \%family;
+		$families_description{$family{'name'}}{'description'} = &load_automatic_lists_description($robot,$family{'name'});
+	    }
+	    $robot_conf->{$robot}{'automatic_list_families'} = \%families_description;
+	}
+	$robot_conf->{$robot}{'automatic_list_families'} ||= $Conf{'automatic_list_families'};
 
 	# split action list for blacklist usage
 	foreach my $action (split(/,/, $Conf{'use_blacklist'})) {
@@ -1274,6 +1318,78 @@ sub load_sql_filter {
     return (&load_generic_conf_file($file,\%sql_named_filter_params, 'abort'));
 }
 
+## load automatic_list_description.conf configuration file
+sub load_automatic_lists_description {
+    my $robot = shift;
+    my $family = shift;
+    &Log::do_log('debug2','Starting: robot %s family %s',$robot,$family);
+    
+    my %automatic_lists_params = (
+	'class' => {
+	    'occurrence' => '1-n',
+	    'format' => { 
+		'name' => {'format' => '.*', 'occurrence' => '1', },
+		'stamp' => {'format' => '.*', 'occurrence' => '1', },
+		'description' => {'format' => '.*', 'occurrence' => '1', },
+		'order' => {'format' => '\d+', 'occurrence' => '1',  },
+		'instances' => {'occurrence' => '1','format' => '.*',},
+		    #'format' => {
+			#'instance' => {
+			    #'occurrence' => '1-n',
+			    #'format' => {
+				#'value' => {'format' => '.*', 'occurrence' => '1', },
+				#'tag' => {'format' => '.*', 'occurrence' => '1', },
+				#'order' => {'format' => '\d+', 'occurrence' => '1',  },
+				#},
+			    #},
+			#},
+		},
+	    },
+	);
+    # find appropriate automatic_lists_description.tt2 file
+    my $config ;
+    if (defined $robot) {
+	$config = $Conf{'etc'}.'/'.$robot.'/families/'.$family.'/automatic_lists_description.conf';
+    }else{
+	$config = $Conf{'etc'}.'/families/'.$family.'/automatic_lists_description.conf';
+    }
+    return undef unless  (-r $config);
+    my $description = &load_generic_conf_file($config,\%automatic_lists_params);
+
+    ## Now doing some structuration work because Conf::load_automatic_lists_description() can't handle
+    ## data structured beyond one level of hash. This needs to be changed.
+    my @structured_data;
+    foreach my $class (@{$description->{'class'}}){
+	my @structured_instances;
+	my @instances = split '%%%',$class->{'instances'};
+	my $default_found = 0;
+	foreach my $instance (@instances) {
+	    my $structured_instance;
+	    my @instance_params = split '---',$instance;
+	    foreach my $instance_param (@instance_params) {
+		$instance_param =~ /^\s*(\S+)\s+(.*)\s*$/;
+		my $key = $1;
+		my $value = $2;
+		$key =~ s/^\s*//;
+		$key =~ s/\s*$//;
+		$value =~ s/^\s*//;
+		$value =~ s/\s*$//;
+		$structured_instance->{$key} = $value;
+	    }
+	    $structured_instances[$structured_instance->{'order'}] = $structured_instance;
+	    if (defined $structured_instance->{'default'}) {
+		$default_found = 1;
+	    }
+	}
+	unless($default_found) {$structured_instances[0]->{'default'} = 1;}
+	$class->{'instances'} = \@structured_instances;
+	$structured_data[$class->{'order'}] = $class;
+    }
+    $description->{'class'} = \@structured_data;
+    return $description;
+}
+
+
 ## load trusted_application.conf configuration file
 sub load_trusted_application {
     my $robot = shift;
@@ -1359,7 +1475,7 @@ sub load_generic_conf_file {
         ## Split in paragraphs
     my $i = 0;
     unless (open (CONFIG, $config_file)) {
-	printf STDERR 'unable to read configuration file %s\n',$config_file;
+	printf STDERR "unable to read configuration file %s\n",$config_file;
 	return undef;
     }
     while (<CONFIG>) {
@@ -1400,14 +1516,14 @@ sub load_generic_conf_file {
 	
 	## Look for first valid line
 	unless ($paragraph[0] =~ /^\s*([\w-]+)(\s+.*)?$/) {
-	    printf STDERR 'Bad paragraph "%s" in %s, ignored', @paragraph, $config_file;
+	    printf STDERR "Bad paragraph '%s' in %s, ignored", @paragraph, $config_file;
 	    return undef if $on_error eq 'abort';
 	    next;
 	}
 	    
 	$pname = $1;	
 	unless (defined $structure{$pname}) {
-	    printf STDERR 'Unknown parameter "%s" in %s, ignored', $pname, $config_file;
+	    printf STDERR "Unknown parameter '%s' in %s, ignored", $pname, $config_file;
 	    return undef if $on_error eq 'abort';
 	    next;
 	}
@@ -1415,7 +1531,7 @@ sub load_generic_conf_file {
 	if (defined $admin{$pname}) {
 	    unless (($structure{$pname}{'occurrence'} eq '0-n') or
 		    ($structure{$pname}{'occurrence'} eq '1-n')) {
-		printf STDERR 'Multiple parameter "%s" in %s', $pname, $config_file;
+		printf STDERR "Multiple parameter '%s' in %s", $pname, $config_file;
 		return undef if $on_error eq 'abort';
 	    }
 	}
@@ -1424,7 +1540,7 @@ sub load_generic_conf_file {
 	if (ref $structure{$pname}{'format'} eq 'HASH') {
 	    ## This should be a paragraph
 	    unless ($#paragraph > 0) {
-		printf STDERR 'Expecting a paragraph for "%s" parameter in %s, ignore it\n', $pname, $config_file;
+		printf STDERR "Expecting a paragraph for '%s' parameter in %s, ignore it\n", $pname, $config_file;
 		return undef if $on_error eq 'abort';
 		next;
 	    }
@@ -1436,13 +1552,13 @@ sub load_generic_conf_file {
 	    for my $i (0..$#paragraph) {	    
 		next if ($paragraph[$i] =~ /^\s*\#/);		
 		unless ($paragraph[$i] =~ /^\s*(\w+)\s*/) {
-		    printf STDERR 'Bad line "%s" in %s\n',$paragraph[$i], $config_file;
+		    printf STDERR "Bad line '%s' in %s\n",$paragraph[$i], $config_file;
 		    return undef if $on_error eq 'abort';
 		}		
 		my $key = $1;
 			
 		unless (defined $structure{$pname}{'format'}{$key}) {
-		    printf STDERR 'Unknown key "%s" in paragraph "%s" in %s\n', $key, $pname, $config_file;
+		    printf STDERR "Unknown key '%s' in paragraph '%s' in %s\n", $key, $pname, $config_file;
 		    return undef if $on_error eq 'abort';
 		    next;
 		}
@@ -1472,7 +1588,7 @@ sub load_generic_conf_file {
 		## Required fields
 		if ($structure{$pname}{'format'}{$k}{'occurrence'} eq '1') {
 		    unless (defined $hash{$k}) {
-			printf STDERR 'Missing key %s in param %s in %s\n', $k, $pname, $config_file;
+			printf STDERR "Missing key %s in param %s in %s\n", $k, $pname, $config_file;
 			return undef if $on_error eq 'abort';
 			$missing_required_field++;
 		    }
@@ -1493,7 +1609,7 @@ sub load_generic_conf_file {
 	    ## This should be a single line
 	    my $xxxmachin =  $structure{$pname}{'format'};
 	    unless ($#paragraph == 0) {
-		printf STDERR 'Expecting a single line for %s parameter in %s %s\n', $pname, $config_file, $xxxmachin ;
+		printf STDERR "Expecting a single line for %s parameter in %s %s\n", $pname, $config_file, $xxxmachin ;
 		return undef if $on_error eq 'abort';
 	    }
 
