@@ -1,5 +1,5 @@
 # Family.pm - This module manages list families
-# RCS Identication ; $Revision: 7327 $ ; $Date: 2012-04-17 05:59:10 +0200 (mar 17 avr 2012) $ 
+# RCS Identication ; $Revision: 7603 $ ; $Date: 2012-09-15 15:41:53 +0200 (sam 15 sep 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -229,6 +229,13 @@ sub new {
 
     $self->{'robot'} = $robot;
 
+    ## Adding configuration related to automatic lists.
+    my $all_families_config = &Conf::get_robot_conf($robot,'automatic_list_families');
+    my $family_config = $all_families_config->{$name};
+    foreach my $key (keys %{$family_config}) {
+	$self->{$key} = $family_config->{$key};
+    }
+
     ## family directory
     $self->{'dir'} = $self->_get_directory();
     unless (defined $self->{'dir'}) {
@@ -335,7 +342,7 @@ sub add_list {
         $hash_list = {config=>$data};
     } else {
 	#copy the xml file in another file
-	unless (open (FIC, '>:utf8', "$self->{'dir'}/_new_list.xml")) {
+	unless (open (FIC, '>', "$self->{'dir'}/_new_list.xml")) {
 	    &do_log('err','Family::add_list(%s) : impossible to create the temp file %s/_new_list.xml : %s',$self->{'name'},$self->{'dir'},$!);
 	}
 	while (<$data>) {
@@ -375,7 +382,7 @@ sub add_list {
     }
 	    
     # config_changes
-    unless (open FILE, '>:utf8', "$list->{'dir'}/config_changes") {
+    unless (open FILE, '>', "$list->{'dir'}/config_changes") {
 	$list->set_status_error_config('error_copy_file',$list->{'name'},$self->{'name'});
 	push @{$return->{'string_info'}}, "Impossible to create file $list->{'dir'}/config_changes : $!, the list is set in status error_config";
     }
@@ -517,7 +524,7 @@ sub modify_list {
     $return->{'string_error'} = undef; ## fatal errors
 
     #copy the xml file in another file
-    unless (open (FIC, '>:utf8', "$self->{'dir'}/_mod_list.xml")) {
+    unless (open (FIC, '>', "$self->{'dir'}/_mod_list.xml")) {
 	&do_log('err','Family::modify_list(%s) : impossible to create the temp file %s/_mod_list.xml : %s',$self->{'name'},$self->{'dir'},$!);
     }
     while (<$fh>) {
@@ -584,9 +591,9 @@ sub modify_list {
 
     ## info file
     unless ($config_changes->{'file'}{'info'}) {
-	$hash_list->{'config'}{'description'} =~ s/\015//g;
+	$hash_list->{'config'}{'description'} =~ s/\r\n|\r/\n/g;
 	
-	unless (open INFO, '>:utf8', "$list->{'dir'}/info") {
+	unless (open INFO, '>', "$list->{'dir'}/info") {
 	    push @{$return->{'string_info'}}, "Impossible to create new $list->{'dir'}/info file : $!";
 	}
 	print INFO $hash_list->{'config'}{'description'};
@@ -603,8 +610,8 @@ sub modify_list {
 	    ################
 #	}
 #	if ($f eq 'info') {
-#	    $hash_list->{'config'}{'description'} =~ s/\015//g;
-#	    unless (open INFO, '>:utf8', "$list_dir/info") {
+#	    $hash_list->{'config'}{'description'} =~ s/\r\n|\r/\n/g;
+#	    unless (open INFO, '>', "$list_dir/info") {
 		################
 #	    }
 #	    print INFO $hash_list->{'config'}{'description'};
@@ -647,7 +654,7 @@ sub modify_list {
 
     }
 
-    unless (open FILE, '>:utf8', "$list->{'dir'}/config_changes") {
+    unless (open FILE, '>', "$list->{'dir'}/config_changes") {
 	$list->set_status_error_config('error_copy_file',$list->{'name'},$self->{'name'});
 	push @{$return->{'string_info'}}, "Impossible to create file $list->{'dir'}/config_changes : $!, the list is set in status error_config.";
     }
@@ -957,7 +964,7 @@ sub instantiate {
 	    }
 	    
 	    # config_changes
-	    unless (open FILE, '>:utf8', "$list->{'dir'}/config_changes") {
+	    unless (open FILE, '>', "$list->{'dir'}/config_changes") {
 		&do_log('err','Family::instantiate : impossible to create file %s/config_changes : %s',$list->{'dir'},$!);
 		push (@{$self->{'generated_lists'}{'file_error'}},$list->{'name'});
 		$list->set_status_error_config('error_copy_file',$list->{'name'},$self->{'name'});
@@ -2173,9 +2180,9 @@ sub _update_existing_list {
 
     ## info file
     unless ($config_changes->{'file'}{'info'}) {
-	$hash_list->{'config'}{'description'} =~ s/\015//g;
+	$hash_list->{'config'}{'description'} =~ s/\r\n|\r/\n/g;
 	
-	unless (open INFO, '>:utf8', "$list->{'dir'}/info") {
+	unless (open INFO, '>', "$list->{'dir'}/info") {
 	    &do_log('err','Impossible to open %s/info : %s',$list->{'dir'},$!);
 	}
 	print INFO $hash_list->{'config'}{'description'};
@@ -2192,8 +2199,8 @@ sub _update_existing_list {
 	    ################
 #	}
 #	if ($f eq 'info') {
-#	    $hash_list->{'config'}{'description'} =~ s/\015//g;
-#	    unless (open INFO, '>:utf8', "$list_dir/info") {
+#	    $hash_list->{'config'}{'description'} =~ s/\r\n|\r/\n/g;
+#	    unless (open INFO, '>', "$list_dir/info") {
 		################
 #	    }
 #	    print INFO $hash_list->{'config'}{'description'};
@@ -2237,7 +2244,7 @@ sub _update_existing_list {
 
     }
 
-    unless (open FILE, '>:utf8', "$list->{'dir'}/config_changes") {
+    unless (open FILE, '>', "$list->{'dir'}/config_changes") {
 	&do_log('err','impossible to open file %s/config_changes : %s',$list->{'dir'},$!);
 	push (@{$self->{'generated_lists'}{'file_error'}},$list->{'name'});
 	$list->set_status_error_config('error_copy_file',$list->{'name'},$self->{'name'});
@@ -2807,8 +2814,69 @@ sub _load_param_constraint_conf {
     return $constraint;
 }
 
+sub create_automatic_list {
+    my $self = shift;
+    my %param = @_;
+    my $auth_level = $param{'auth_level'};
+    my $sender = $param{'sender'};
+    my $message = $param{'message'};
+    my $listname = $param{'listname'};
 
+    unless ($self->is_allowed_to_create_automatic_lists(%param)){
+	&Log::do_log('err', 'Unconsistent scenario evaluation result for automatic list creation of list %s@%s by user %s.', $listname,$self->{'robot'},$sender);
+	return undef;
+    }
+    my $result = $self->add_list({listname=>$listname}, 1);
+    
+    unless (defined $result->{'ok'}) {
+	my $details = $result->{'string_error'} || $result->{'string_info'} || [];
+	&Log::do_log('err', "Failed to add a dynamic list to the family %s : %s", $self->{'name'}, join(';', @{$details}));
+	return undef;
+    }
+    my $list = new List ($listname, $self->{'robot'});
+    unless (defined $list) {
+	&Log::do_log('err', 'sympa::DoFile() : dynamic list %s could not be created',$listname);
+	return undef;
+    }
+    return $list;
+}
 
+# Returns 1 if the user is allowed to create lists based on the family.
+sub is_allowed_to_create_automatic_lists {
+    my $self = shift;
+    my %param = @_;
+    
+    my $auth_level = $param{'auth_level'};
+    my $sender = $param{'sender'};
+    my $message = $param{'message'};
+    my $listname = $param{'listname'};
+    
+    # check authorization
+    my $result = &Scenario::request_action('automatic_list_creation',$auth_level,$self->{'robot'},
+					   {'sender' => $sender, 
+					    'message' => $message, 
+					    'family'=>$self, 
+					    'automatic_listname'=>$listname });
+    my $r_action;
+    unless (defined $result) {
+	&Log::do_log('err', 'Unable to evaluate scenario "automatic_list_creation" for family %s', $self->{'name'});
+	return undef;
+    }
+    
+    if (ref($result) eq 'HASH') {
+	$r_action = $result->{'action'};
+    }else {
+	&Log::do_log('err', 'Unconsistent scenario evaluation result for automatic list creation in family %s', $self->{'name'});
+	return undef;
+    }
+
+    unless ($r_action =~ /do_it/) {
+	&Log::do_log('debug2', 'Automatic list creation refused to user %s for family %s', $sender, $self->{'name'});
+	return undef;
+    }
+    
+    return 1;
+}
 =pod 
 
 =head1 AUTHORS 
