@@ -1,5 +1,5 @@
 # Log.pm - This module includes all Logging-related functions
-# RCS Identication ; $Revision: 6556 $ ; $Date: 2010-06-21 18:01:01 +0200 (lun 21 jun 2010) $ 
+# RCS Identication ; $Revision: 7436 $ ; $Date: 2012-06-27 11:26:32 +0200 (mer 27 jun 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -90,10 +90,12 @@ sub do_log {
     my $errno = $!;
 
     ## Do not display variables which are references.
-    foreach my $i (0..$#param) {
-        if (ref($param[$i])){
-            $param[$i] = ref($param[$i])
-        }
+    foreach my $p (@param) {
+	unless (defined $p) {
+	    $p = ''; # prevent 'Use of uninitialized value' warning
+	} elsif (ref $p) {
+	    $p = ref $p;
+	}
     }
 
     ## Determine calling function and parameters
