@@ -30,6 +30,7 @@ use List;
 use Log;
 use Conf;
 use Sympa::Constants;
+use Data::Dumper;
 
 my %all_scenarios;
 my %persistent_cache;
@@ -142,7 +143,7 @@ sub new {
 
     ## Keep the scenario in memory
     $all_scenarios{$scenario->{'file_path'}} = $scenario;
-    
+
     return $scenario;
 }
 
@@ -172,6 +173,7 @@ sub _parse_scenario {
         
 	if ($current_rule =~ /\s*(include\s*\(?\'?(.*)\'?\)?)\s*$/i) {
 	    $rule->{'condition'} = $1;
+	    push(@scenario, $rule);
 	}elsif ($current_rule =~ /^\s*(.*?)\s+((\s*(md5|pgp|smtp|smime|dkim)\s*,?)*)\s*->\s*(.*)\s*$/gi) {
 	    $rule->{'condition'} = $1;
 	    $rule->{'action'} = $5;
@@ -388,7 +390,6 @@ sub request_action {
 	## Add rules at the beginning of the array
 	unshift @rules, @{$include_scenario->{'rules'}};
     }
-
     ## Look for 'include' directives amongst rules first
     foreach my $index (0..$#rules) {
 	if ($rules[$index]{'condition'} =~ /^\s*include\s*\(?\'?([\w\.]+)\'?\)?\s*$/i) {
@@ -546,8 +547,8 @@ sub verify {
     
     if (defined ($context->{'msg'})) {
 	my $header = $context->{'msg'}->head;
-	unless (($header->get('to') && ($header->get('to') =~ /$context->{'listname'}/i)) || 
-		($header->get('cc') && ($header->get('cc') =~ /$context->{'listname'}/i))) {
+	unless (($header->get('to') && (join(', ', $header->get('to')) =~ /$context->{'listname'}/i)) || 
+		($header->get('cc') && (join(', ', $header->get('cc')) =~ /$context->{'listname'}/i))) {
 	    $context->{'is_bcc'} = 1;
 	}else{
 	    $context->{'is_bcc'} = 0;
@@ -589,6 +590,11 @@ sub verify {
 	    $value =~ s/\[custom_vars\-\>([\w\-]+)\]/$context->{'custom_vars'}{$1}/;
 	}
 	
+	## Family vars
+	if ($value =~ /\[family\-\>([\w\-]+)\]/i) {
+	    $value =~ s/\[family\-\>([\w\-]+)\]/$context->{'family'}{$1}/;
+	}
+	
 	## Config param
 	elsif ($value =~ /\[conf\-\>([\w\-]+)\]/i) {
 	    if (my $conf_value = &Conf::get_robot_conf($robot, $1)) {
@@ -667,14 +673,12 @@ sub verify {
 	    return -1 * $negation unless (defined ($context->{'msg'}));
 	    
 	    my @bodies;
-	    my @parts = $context->{'msg'}->parts();
-	    
-	    ## Should be recurcive...
-	    foreach my $i (0..$#parts) {
-		next unless ($parts[$i]->effective_type() =~ /^text/);
-		next unless (defined $parts[$i]->bodyhandle);
+	    ## FIXME:Should be recurcive...
+	    foreach my $part ($context->{'msg'}->parts) {
+		next unless ($part->effective_type() =~ /^text/);
+		next unless (defined $part->bodyhandle);
 		
-		push @bodies, $parts[$i]->bodyhandle->as_string();
+		push @bodies, $part->bodyhandle->as_string();
 	    }
 	    $value = \@bodies;
 	    
@@ -682,9 +686,8 @@ sub verify {
 	    return -1 * $negation unless (defined ($context->{'msg'}));
 	    
 	    my @types;
-	    my @parts = $context->{'msg'}->parts();
-	    foreach my $i (0..$#parts) {
-		push @types, $parts[$i]->effective_type();
+	    foreach my $part ($context->{'msg'}->parts) {
+		push @types, $part->effective_type();
 	    }
 	    $value = \@types;
 
@@ -857,16 +860,29 @@ sub verify {
             $regexp =~ s/\[host\]/$reghost/g ;
 	}
 
+	# wrap matches with eval{} to avoid crash by malformed regexp.
+	my $r = 0;
 	if (ref($args[0])) {
-	    foreach my $arg (@{$args[0]}) {
-		return $negation 
-		    if ($arg =~ /$regexp/i);
-	    }
-	}else {
-	    if ($args[0] =~ /$regexp/i) {
-		return $negation ;
-	    }
+	    eval {
+		foreach my $arg (@{$args[0]}) {
+		    if ($arg =~ /$regexp/i) {
+			$r = 1;
+			last;
+		    }
+		}
+	    };
+	} else {
+	    eval {
+		if ($args[0] =~ /$regexp/i) {
+		    $r = 1;
+		}
+	    };
 	}
+	if ($@) {
+	    &do_log('err', 'cannot evaluate match: %s', $@);
+	    return undef;
+	}
+	return $negation if $r;
 	
 	return -1 * $negation ;
 
@@ -895,12 +911,11 @@ sub verify {
 	    foreach my $arg (@{$args[0]}) {
 		&do_log('debug3', 'ARG: %s', $arg);
 		return $negation 
-		    if ($arg =~ /^$args[1]$/i);
-	    }
-	}else {
-	    if ($args[0] =~ /^$args[1]$/i) {
-		return $negation ;
+		    if lc($arg) eq lc($args[1]);
 	    }
+	} else {
+	    return $negation
+		if lc($args[0]) eq lc($args[1]);
 	}
 	return -1 * $negation ;
     }
@@ -1198,4 +1213,16 @@ sub dump_all_scenarios {
     close TMP;
 }
 
+sub is_purely_closed {
+    my $self = shift;
+    foreach my $rule (@{$self->{'rules'}}) {
+	if ($rule->{'condition'} ne 'true' && $rule->{'action'} !~ /reject/) {
+	    Log::do_log('debug2','Scenario %s is not purely closed.',$self->{'title'});
+	    return 0;
+	}
+    }
+    Log::do_log('notice','Scenario %s is purely closed.',$self->{'file_path'});
+    return 1;
+}
+
 1;
