@@ -479,17 +479,30 @@ our @params = (
     {
         name    => 'automatic_list_feature',
         default => 'off',
-	vhost   => '1',
+        vhost   => '1',
     },
     {
         name    => 'automatic_list_creation',
         default => 'public',
-	vhost   => '1',
+        vhost   => '1',
     },
     {
         name    => 'automatic_list_removal',
         default => '', ## Can be 'if_empty'
-	vhost   => '1',
+        vhost   => '1',
+    },
+    {
+        name    => 'automatic_list_families',
+        query   => 'Defines the name of the family the automatic lists are based on.', 
+        file    => 'sympa.conf',
+        optional => '1',
+        vhost   => '1',
+    },
+    {
+        name    => 'automatic_list_prefix',
+        query   => 'Defines the prefix allowing to recognize that a list is an automatic list.', 
+        file    => 'sympa.conf',
+        optional => '1',
     },
     {
         name    => 'global_remind',
@@ -534,8 +547,8 @@ our @params = (
     { title => 'Internationalization' },
     {
         name    => 'lang',
-        default => 'en_US',
-        query   => 'Default lang (ca | cs | de | el | es | et_EE | en_US | fr | fi | hu | it | ja_JP | ko | nl | nb_NO | oc | pl | pt_BR | ru | sv | tr | vi | zh_CN | zh_TW)',
+        default => 'en',
+        query   => 'Default lang (ca | cs | de | el | es | et_EE | en | fr | fi | hu | it | ja_JP | ko | nl | nb_NO | oc | pl | pt_BR | ru | sv | tr | vi | zh_CN | zh_TW)',
 	vhost   => '1',
         file    => 'sympa.conf',
         edit    => '1',
@@ -543,7 +556,7 @@ our @params = (
     },
     {
         name    => 'supported_lang',
-        default => 'ca,cs,de,el,es,et_EE,en_US,fr,fi,hu,it,ja_JP,ko,nl,nb_NO,oc,pl,pt_BR,ru,sv,tr,vi,zh_CN,zh_TW',
+        default => 'ca,cs,de,el,es,et_EE,en,fr,fi,hu,it,ja_JP,ko,nl,nb_NO,oc,pl,pt_BR,ru,sv,tr,vi,zh_CN,zh_TW',
         query   => 'Supported languages',
 	vhost   => '1',
         file    => 'sympa.conf',
@@ -699,13 +712,13 @@ our @params = (
 	optional => '1',
 	file   => 'sympa.conf',
     },
-    {
-	name => 'dkim_header_list',
-        vhost => '1',
-	file   => 'sympa.conf',
-        query   => 'list of headers to be included ito the message for signature', 
-        default => 'from:sender:reply-to:subject:date:message-id:to:cc:list-id:list-help:list-unsubscribe:list-subscribe:list-post:list-owner:list-archive:in-reply-to:references:resent-date:resent-from:resent-sender:resent-to:resent-cc:resent-message-id:mime-version:content-type:content-transfer-encoding:content-id:content-description', 
-    }, 
+    ##{
+	##name => 'dkim_header_list',
+        ##vhost => '1',
+	##file   => 'sympa.conf',
+        ##query   => 'list of headers to be included ito the message for signature', 
+        ##default => 'from:sender:reply-to:subject:date:message-id:to:cc:list-id:list-help:list-unsubscribe:list-subscribe:list-post:list-owner:list-archive:in-reply-to:references:resent-date:resent-from:resent-sender:resent-to:resent-cc:resent-message-id:mime-version:content-type:content-transfer-encoding:content-id:content-description', 
+    ##}, 
     { 'title' => 'S/MIME pluggin' },
     {
         name   => 'openssl',
