@@ -1,5 +1,5 @@
 # mail.pm - This module includes mail sending functions and does the smtp job.
-# RCS Identication ; $Revision: 6752 $ ; $Date: 2010-11-17 08:23:05 +0100 (mer 17 nov 2010) $ 
+# RCS Identication ; $Revision: 7551 $ ; $Date: 2012-08-04 12:02:48 +0200 (sam 04 aoû 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -26,6 +26,7 @@ use strict;
 use Exporter;
 use Carp;
 use POSIX qw(sysconf);
+use Time::Local;
 use MIME::Charset;
 use MIME::Tools;
 
@@ -42,7 +43,7 @@ our @EXPORT = qw(mail_file mail_message mail_forward set_send_spool);
 
 
 ## RCS identification.
-#my $id = '@(#)$Id: mail.pm 6752 2010-11-17 07:23:05Z david.verdin $';
+#my $id = '@(#)$Id: mail.pm 7551 2012-08-04 10:02:48Z sikeda $';
 
 my $opensmtp = 0;
 my $fh = 'fh0000000000';	## File handle for the stream.
@@ -105,7 +106,6 @@ sub set_send_spool {
 #            -d : d=tag
 #            -i : i=tag (optionnal)
 #            -selector : dkim dns selector
-#            -header_list : headers part of the signed infos
 #            -key : the RSA private key
 #      -$robot(+)
 #      -$sign_mode :'smime' | '' | undef
@@ -169,7 +169,7 @@ sub mail_file {
 		last;
 	    }
 		
-	    foreach my $header ('to','from','subject','reply-to','mime-version', 'content-type','content-transfer-encoding') {
+	    foreach my $header ('date', 'to','from','subject','reply-to','mime-version', 'content-type','content-transfer-encoding') {
 		if ($line=~/^$header:/i) {
 		    $header_ok{$header} = 1;
 		    last;
@@ -181,8 +181,28 @@ sub mail_file {
     ## ADD MISSING HEADERS
     my $headers="";
 
-    unless ($header_ok{'to'}) {
+    unless ($header_ok{'date'}) {
+	my $now = time;
+	my $tzoff = timegm(localtime $now) - $now;
+	my $sign;
+	if ($tzoff < 0) {
+	   ($sign, $tzoff) = ('-', -$tzoff);
+	} else {
+	   $sign = '+';
+	}
+	$tzoff = sprintf '%s%02d%02d',
+			 $sign, int($tzoff / 3600), int($tzoff / 60) % 60;
+	Language::PushLang('en');
+	$headers .= 'Date: ' .
+		    POSIX::strftime("%a, %d %b %Y %H:%M:%S $tzoff",
+				    localtime $now) .
+		    "\n";
+	Language::PopLang();
+    }
 
+    unless ($header_ok{'to'}) {
+	# Currently, bare e-mail address is assumed.  Complex ones such as
+	# "phrase" <email> won't be allowed.
 	if (ref ($rcpt)) {
 	    if ($data->{'to'}) {
 		$to = $data->{'to'};
@@ -192,10 +212,7 @@ sub mail_file {
 	}else{
 	    $to = $rcpt;
 	}   
-	$headers .= "To: ".MIME::EncWords::encode_mimewords(
-	    Encode::decode('utf8', $to),
-	    'Encoding' => 'A', 'Charset' => $data->{'charset'}, 'Field' => 'To'
-	    )."\n"; 
+	$headers .= "To: $to\n";
     }     
     unless ($header_ok{'from'}) {
 	if ($data->{'from'} eq 'sympa') {
@@ -369,6 +386,12 @@ sub mail_message {
     my @sendto;
     my @sendtobypacket;
 
+    my $cmd_size = length(&Conf::get_robot_conf($robot, 'sendmail')) + 1 +
+		   length(&Conf::get_robot_conf($robot, 'sendmail_args')) +
+		   length(' -N success,delay,failure -V ') + 32 +
+		   length(" -f $from ");
+    my $db_type = $Conf::Conf{'db_type'};
+
     while (defined ($i = shift(@rcpt))) {
 	my @k = reverse(split(/[\.@]/, $i));
 	my @l = reverse(split(/[\.@]/, $j));
@@ -381,28 +404,30 @@ sub mail_message {
 	$rcpt_by_dom{$dom} += 1 ;
 	&do_log('debug2', "domain: $dom ; rcpt by dom: $rcpt_by_dom{$dom} ; limit for this domain: $Conf::Conf{'nrcpt_by_domain'}{$dom}");
 
-	if (defined ($Conf::Conf{'nrcpt_by_domain'}{$dom}) && ( $rcpt_by_dom{$dom} >= $Conf::Conf{'nrcpt_by_domain'}{$dom} )){
-	    undef %rcpt_by_dom ;
-	    my @tab =  @sendto ; push @sendtobypacket, \@tab ;# do not replace this line by push @sendtobypacket, \@sendto !!!
-	    $numsmtp++ ; # if (&sendto($msg_header, $msg_body, $from, \@sendto, $robot));
+	if (
+	    # number of recipients by each domain
+	    (defined $Conf::Conf{'nrcpt_by_domain'}{$dom} and
+	     $rcpt_by_dom{$dom} >= $Conf::Conf{'nrcpt_by_domain'}{$dom}) or
+	    # number of different domains
+	    ($j and $#sendto >= &Conf::get_robot_conf($robot, 'avg') and
+	     lc "$k[0] $k[1]" ne lc "$l[0] $l[1]") or
+	    # number of recipients in general, and ARG_MAX limitation
+	    ($#sendto >= 0 and
+	     ($cmd_size + $size + length($i) + 5 > $max_arg or
+	      $nrcpt >= &Conf::get_robot_conf($robot, 'nrcpt'))) or
+	    # length of recipients field stored into bulkmailer table
+	    # (these limits might be relaxed by future release of Sympa)
+	    ($db_type eq 'mysql' and $size + length($i) + 5 > 65535) or
+	    ($db_type !~ /^(mysql|SQLite)$/ and $size + length($i) + 5 > 500)
+	   ) {
+	    undef %rcpt_by_dom;
+	    # do not replace this line by "push @sendtobypacket, \@sendto" !!!
+	    my @tab =  @sendto; push @sendtobypacket, \@tab;
+	    $numsmtp++;
 	    $nrcpt = $size = 0;
 	    @sendto = ();
 	}
 	
-	if ($j && $#sendto >= &Conf::get_robot_conf($robot, 'avg') && lc("$k[0] $k[1]") ne lc("$l[0] $l[1]")) {
-	    undef %rcpt_by_dom ;
-	    $numsmtp++ ; # if (&sendto($msg_header, $msg_body, $from, \@sendto, $robot));
-	    my @tab =  @sendto ; push @sendtobypacket, \@tab ;# do not replace this line by push @sendtobypacket, \@sendto !!!
-	    $nrcpt = $size = 0;
-	    @sendto = ();
-	}
-	if ($#sendto >= 0 && (($size + length($i)) > $max_arg || $nrcpt >= &Conf::get_robot_conf($robot, 'nrcpt'))) {
-	    undef %rcpt_by_dom ;
-	    $numsmtp++  ; # if (&sendto($msg_header, $msg_body, $from, \@sendto, $robot));
-	    my @tab =  @sendto ; push @sendtobypacket, \@tab ;# do not replace this line by push @sendtobypacket, \@sendto !!!
-	    $nrcpt = $size = 0;
-	    @sendto = ();
-	}
 	$nrcpt++; $size += length($i) + 5;
 	push(@sendto, $i);
 	$j = $i;
@@ -809,7 +834,7 @@ sub smtpto {
    
 
    if (!pipe(IN, OUT)) {
-       fatal_err(sprintf gettext("Unable to create a channel in smtpto: %m"), $!); ## No return
+       fatal_err(sprintf gettext("Unable to create a channel in smtpto: %s"), "$!"); ## No return
        }
    $pid = &tools::safefork();
    $pid{$pid} = 0;
