@@ -1,5 +1,5 @@
 # SharedDocument.pm - module to manipulate shared web documents
-# <!-- RCS Identication ; $Revision: 3539 $ ; $Date: 2006-02-02 14:10:35 +0100 (jeu, 02 fév 2006) $ -->
+# <!-- RCS Identication ; $Revision: 5958 $ ; $Date: 2009-07-10 16:44:46 +0200 (ven 10 jui 2009) $ -->
 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
@@ -23,15 +23,13 @@
 package SharedDocument;
 
 use strict;
-require Exporter;
-require 'tools.pl';
-my @ISA = qw(Exporter);
-my @EXPORT = qw();
 
 use Carp;
+use POSIX;
+
+use tools;
 use List;
 use Log;
-use POSIX;
 
 ## Creates a new object
 sub new {
@@ -476,6 +474,4 @@ sub check_access_control {
     return 1;
 }
 
-
-## Packages must return true.
 1;
