@@ -1,5 +1,5 @@
 # wwslib.pm - This module includes functions used by wwsympa.fcgi
-# RCS Identication ; $Revision: 6098 $ ; $Date: 2009-08-13 10:26:28 +0200 (jeu 13 aoû 2009) $ 
+# RCS Identication ; $Revision: 7434 $ ; $Date: 2012-06-25 09:33:43 +0200 (lun 25 jun 2012) $ 
 #
 # Sympa - SYsteme de Multi-Postage Automatique
 # Copyright (c) 1997, 1998, 1999, 2000, 2001 Comite Reseau des Universites
@@ -44,7 +44,8 @@ use Sympa::Constants;
 		  60    => {'gettext_id' => "1 hour"},
 		  360   => {'gettext_id' => "6 hours"},
 		  1440  => {'gettext_id' => "1 day"}, 
-		  43200 => {'gettext_id' => "1 week"});
+		  10800 => {'gettext_id' => "1 week"},
+		  43200 => {'gettext_id' => "30 days"});
 
 %visibility_mode = ('noconceal' => {'gettext_id' => "listed in the list review page"},
 		    'conceal' => {'gettext_id' => "concealed"}
@@ -342,7 +343,7 @@ sub get_my_url {
 	$return_url = 'http';	
     }	     
 
-    $return_url .= '://'.$ENV{'HTTP_HOST'};
+    $return_url .= '://'.&main::get_header_field('HTTP_HOST');
     $return_url .= ':'.$ENV{'SERVER_PORT'} unless (($ENV{'SERVER_PORT'} eq '80')||($ENV{'SERVER_PORT'} eq '443'));
     $return_url .= $ENV{'REQUEST_URI'};
     return ($return_url);
